/*
 * ArrayFunctions.java
 *
 * version: 22nd October 2008, 15:11
 * author: yanas
 */
package cz.yanas.pb162.arrays;

import java.util.Arrays;

/**
 * This class demonstrates working with one-dimensional arrays in Java. See following
 * Javadoc for further details.
 *
 * @author yanas
 */
public final class ArrayFunctions {

    /**
     * Returns the minimum int value of the given int values.
     * 
     * @param values an array of int values
     *
     * @return the minimum int value of the given int values
     */
    public static int min(int[] values) {
        int min = Integer.MAX_VALUE;

        for (int value : values) {
            if (value < min) {
                min = value;
            }
        }

        return min;
    }

    /**
     * Returns the maximum int value of the given int values.
     * 
     * @param values an array of int values
     *
     * @return the maximum int value of the given int values
     */
    public static int max(int[] values) {
        int max = Integer.MIN_VALUE;

        for (int value : values) {
            if (value > max) {
                max = value;
            }
        }

        return max;
    }

    /**
     * Returns the mean of the given int values.
     * 
     * @param values an array of int values
     *
     * @return the mean of the given int values
     */
    public static float mean(int[] values) {
        float sum = 0;

        for (int value : values) {
            sum += value;
        }

        return (sum / values.length);
    }

    /**
     * Returns the median of the given int values.
     * 
     * @param values an array of int values
     *
     * @return the median of the given int values
     */
    public static int median(int[] values) {
        int[] copy = Arrays.copyOf(values, values.length);
        Arrays.sort(copy);

        return copy[copy.length / 2];
    }

    /**
     * Returns the product of the given int values.
     * 
     * @param values an array of int values
     *
     * @return the product of the given int values
     */
    public static int product(int[] values) {
        int result = 1;

        for (int value : values) {
            result *= value;
        }

        return result;
    }

    /**
     * Prints the given values using the System.out.println method.
     * 
     * @param values an array of int values with variable length
     */
    public static void printValues(int... values) {
        for (int value : values) {
            System.out.println(value);
        }
    }

}
