/*
 * Main.java
 *
 * version: 22nd October 2008, 15:11
 * author: yanas
 */
package cz.yanas.pb162.arrays;

import java.util.Arrays;

/**
 * This class demonstrates the use of the ArrayFunctions class.
 *
 * @author yanas
 */
public final class Main {

    /**
     * Entry point of the application.
     * 
     * This method is used to "execute" the ArrayFunctions class with two arguments.
     * The first argument is the function to be called.
     * The second argument represents a list of integers separated by whitespace.
     * 
     * Based on the first argument, the corresponding method is called using the list
     * of integers provided. The result is printed to standard output.
     * 
     * @param args an array of arguments passed from command line (terminal)
     */
    public static void main(String[] args) {
        // exactly two arguments are expected
        if (args.length != 2) {
            // print an error message and exit the method with an error code
            System.err.println("Please provide both arguments!");
            System.exit(-1);
        }

        // take the second argument, trim trailing whitespace and split it into an array
        // we use a REGEXP (regular expression) to do that
        String trimmedString = args[1].trim();
        String[] splitString = trimmedString.split("\\s+");

        // prepare an array of integers of equal length
        int[] integers = new int[splitString.length];

        // loop through all the integers that are still stored as strings
        for (int i = 0; i < splitString.length; i++) {
            // convert string integer to corresponding int value
            // we cannot simply cast an instance of the String class to an int value!
            integers[i] = Integer.parseInt(splitString[i]);
        }

        // print out all the integers to check if we made the conversion right
        // notice that we use the handy Arrays class here, it won't work without it
        System.out.println("integers:");
        System.out.println(Arrays.toString(integers));
        System.out.println();

        // get the action (name of the method to be called) and print the action
        String action = args[0];
        System.out.println(action + ":");

        // based on the action call the right method and print the result
        if (action.equals("min")) {
            System.out.println(ArrayFunctions.min(integers));
        } else if (action.equals("max")) {
            System.out.println(ArrayFunctions.max(integers));
        } else if (action.equals("mean")) {
            System.out.println(ArrayFunctions.mean(integers));
        } else if (action.equals("median")) {
            System.out.println(ArrayFunctions.median(integers));
        } else if (action.equals("product")) {
            System.out.println(ArrayFunctions.product(integers));
        } else {
            // or print an error message if the action is invalid
            System.err.println("The action is invalid!");
        }

        // print a new line only
        System.out.println();

        // test the method with variable number of parameters
        System.out.println("printValues():");
        ArrayFunctions.printValues(1, 2, 3, 4, 5);
        System.out.println();
    }

    private Main() {
    }

}
